@@ -31,13 +31,14 @@ def get_parser():  # pragma: no cover
     return parser
 
 
-def run():  # pragma: no cover
-    parser = get_parser()
+def run(parser):  # pragma: no cover
     args = parser.parse_args()
     data = vars(args)
     dispatcher_class = data.pop('dispatcher')
     dispatcher = dispatcher_class()
     dispatcher.run(**data)
 
-if __name__ == '__main__':  # pragma: no cover
-    run()
+
+def main():  # pragma: no cover
+    parser = get_parser()
+    run(parser)
